LibRadar
===================

LibRadar is an automatic tool for third-party library (SDK) detection of Android apps.


Fast
-------------------

LibRadar takes just several seconds to scan an app and report the list of third-party libraries used in it.

Accurate
-------------------

LibRadar is trained with more than 1 million apps from Google Play, so it can identify virtually all popular libraries in any given Android app.

Anti-Obfuscation
-------------------

Many Android apps are obfuscated with tools such as ProGuard, which makes it difficult to recognize a library by its package names or class names.
LibRadar is obfuscation-resilient since we use features that cannot be obfuscated, such as statistics on Android APIs.
